jacinle.utils.defaults
======================

.. automodule:: jacinle.utils.defaults

   
   
   .. rubric:: Module attributes

   .. autosummary::
   
      ARGDEF
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      DefaultsManager
      FileOptions
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      default_args
      gen_get_default
      gen_set_default
      option_context
      wrap_custom_as_default
   
   

   
   
   








.. rubric:: Class DefaultsManager
.. autoclass:: DefaultsManager
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class FileOptions
.. autoclass:: FileOptions
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: default_args

.. autofunction:: gen_get_default

.. autofunction:: gen_set_default

.. autofunction:: option_context

.. autofunction:: wrap_custom_as_default


